==> edge-login-ui-rn-0.9.23.tgz: package/lib/reducers/LoginReducer.js <==
const initialState = {
    errorMessage: null,
    isLoggingInWithPin: false,
    loginSuccess: false,
    otpAttempt: null,
    otpError: null,
    pin: null,
    username: '',
    wait: 0
};
export function login(state = initialState, action) {
    switch (action.type) {
        case 'SET_PREVIOUS_USERS': {
            const { startupUser } = action.data;
            if (startupUser != null) {
                return Object.assign(Object.assign({}, state), { username: startupUser.username });
            }
            return state;
        }
        case 'AUTH_UPDATE_USERNAME':
            return Object.assign(Object.assign({}, state), { username: action.data, errorMessage: null, wait: 0 });
        case 'UPDATE_WAIT_TIMER':
            return Object.assign(Object.assign({}, state), { wait: action.data.seconds });
        case 'AUTH_UPDATE_PIN':
            return Object.assign(Object.assign({}, state), { pin: action.data, errorMessage: null });
        case 'LOGIN_SUCCEESS':
            return Object.assign(Object.assign({}, state), { loginSuccess: true, isLoggingInWithPin: false, errorMessage: null, wait: 0 });
        case 'LOGIN_PIN_FAIL':
            return Object.assign(Object.assign({}, state), { errorMessage: action.data.message, wait: action.data.wait, pin: '', isLoggingInWithPin: false });
        case 'AUTH_LOGGING_IN_WITH_PIN':
            return Object.assign(Object.assign({}, state), { isLoggingInWithPin: true });
        case 'OTP_ERROR':
            return Object.assign(Object.assign({}, state), { otpAttempt: action.data.attempt, otpError: action.data.error, otpResetDate: action.data.error.resetDate });
        case 'START_OTP_REPAIR':
            return Object.assign(Object.assign({}, state), { otpError: action.data.error, otpResetDate: action.data.error.resetDate });
        case 'OTP_RESET_REQUEST':
            return Object.assign(Object.assign({}, state), { otpResetDate: action.data });
        case 'RESET_APP': {
            const username = state.username;
            return Object.assign(Object.assign({}, initialState), { username: username });
        }
        // Actions for launching scenes:
        case 'START_RECOVERY_LOGIN':
            return Object.assign(Object.assign({}, state), { username: action.data.username, errorMessage: null, wait: 0 });
        default:
            return state;
    }
}

==> edge-login-ui-rn-2.1.0.tgz: package/lib/reducers/LoginReducer.js <==
const initialState = {
    errorMessage: null,
    isLoggingInWithPin: false,
    loginSuccess: false,
    pin: null,
    username: '',
    wait: 0
};
export function login(state = initialState, action) {
    switch (action.type) {
        case 'SET_PREVIOUS_USERS': {
            const { startupUser } = action.data;
            if (startupUser != null) {
                return Object.assign(Object.assign({}, state), { username: startupUser.username });
            }
            return state;
        }
        case 'AUTH_UPDATE_USERNAME':
            return Object.assign(Object.assign({}, state), { username: action.data, errorMessage: null, wait: 0 });
        case 'AUTH_UPDATE_PIN':
            return Object.assign(Object.assign({}, state), { pin: action.data, errorMessage: null });
        case 'LOGIN_SUCCEESS':
            return Object.assign(Object.assign({}, state), { loginSuccess: true, isLoggingInWithPin: false, errorMessage: null, wait: 0 });
        case 'LOGIN_PIN_FAIL':
            return Object.assign(Object.assign({}, state), { errorMessage: action.data.message, wait: action.data.wait, pin: '', isLoggingInWithPin: false });
        case 'AUTH_LOGGING_IN_WITH_PIN':
            return Object.assign(Object.assign({}, state), { isLoggingInWithPin: true });
        case 'NAVIGATE':
            switch (action.data.name) {
                case 'recoveryLogin': {
                    const { username } = action.data.params;
                    return Object.assign(Object.assign({}, state), { username, errorMessage: null, wait: 0 });
                }
            }
            return state;
        case 'RESET_APP': {
            const username = state.username;
            return Object.assign(Object.assign({}, initialState), { username: username });
        }
        default:
            return state;
    }
}
